@@ -7,7 +7,7 @@ use Thread::Tie ();
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-$VERSION = '0.20';
+$VERSION = '0.21';
 use strict;
 
 # Make sure we only load stuff when we actually need it
@@ -121,7 +121,7 @@ Thread::Conveyor - transport of any data-structure between threads
 
 =head1 VERSION
 
-This documentation describes version 0.20.
+This documentation describes version 0.21.
 
 =head1 SYNOPSIS
 
@@ -453,7 +453,9 @@ there for an up-to-date status of what can be passed around between threads.
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
 
-Please report bugs to <perlbugs@dijkmat.nl>.
+Maintained by LNATION <email@lnation.org>
+
+Please report bugs to <email@lnation.org>.
 
 =head1 HISTORY
 
@@ -500,7 +502,7 @@ ba accomplished with the "clean" and "clean_dontwait" methods.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002, 2003, 2004, 2007, 2010 Elizabeth Mattijsen <liz@dijkmat.nl>.
+Copyright (c) 2002, 2003, 2004, 2007, 2010 Elizabeth Mattijsen <liz@dijkmat.nl>. 2025 LNATION <email@lnation.org>
 All rights reserved.  This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
 
